@@ -1,11 +1,14 @@
+import abc
 import math
 
 import numpy as np
 from numpy.typing import NDArray
 
+from libecalc.common.energy_model_type import EnergyModelType
 from libecalc.common.errors.exceptions import IllegalStateException
 from libecalc.common.logger import logger
 from libecalc.common.units import UnitConstants
+from libecalc.domain.component_validation_error import ProcessPressureRatioValidationException
 from libecalc.domain.process.compressor.core.results import (
     CompressorTrainResultSingleTimeStep,
     CompressorTrainStageResultSingleTimeStep,
@@ -18,10 +21,7 @@ from libecalc.domain.process.compressor.core.train.utils.enthalpy_calculations i
     calculate_polytropic_head_campbell,
 )
 from libecalc.domain.process.compressor.core.utils import map_compressor_train_stage_to_domain
-from libecalc.domain.process.compressor.dto import (
-    CompressorTrainSimplifiedWithKnownStages,
-    CompressorTrainSimplifiedWithUnknownStages,
-)
+from libecalc.domain.process.compressor.dto import CompressorStage
 from libecalc.domain.process.value_objects.chart.chart_area_flag import ChartAreaFlag
 from libecalc.domain.process.value_objects.chart.compressor import VariableSpeedCompressorChart
 from libecalc.domain.process.value_objects.chart.compressor.chart_creator import CompressorChartCreator
@@ -29,7 +29,7 @@ from libecalc.domain.process.value_objects.fluid_stream import FluidStream, Proc
 from libecalc.domain.process.value_objects.fluid_stream.fluid_factory import FluidFactoryInterface
 
 
-class CompressorTrainSimplified(CompressorTrainModel):
+class CompressorTrainSimplified(CompressorTrainModel, abc.ABC):
     """A simplified model of a compressor train.
 
     In general, a compressor train (series of compressors) are running with the same shaft, meaning they will always
@@ -79,21 +79,25 @@ class CompressorTrainSimplified(CompressorTrainModel):
       given and the generic unified chart is scaled by these.
     """
 
-    def check_for_undefined_stages(
+    @abc.abstractmethod
+    def define_undefined_stages(
         self,
-        rate: NDArray[np.float64],
         suction_pressure: NDArray[np.float64],
         discharge_pressure: NDArray[np.float64],
+    ): ...
+
+    def check_for_undefined_stages(
+        self,
     ) -> None:
         # All stages are there, but compressor chart can still be None (GENERIC_FROM_INPUT)
         self.stages = self.define_undefined_stages(
-            suction_pressure=suction_pressure,
-            discharge_pressure=discharge_pressure,
+            suction_pressure=self._suction_pressure,
+            discharge_pressure=self._discharge_pressure,
         )
         pressure_ratios_per_stage = self.calculate_pressure_ratios_per_stage(
-            suction_pressure=suction_pressure, discharge_pressure=discharge_pressure
+            suction_pressure=self._suction_pressure, discharge_pressure=self._discharge_pressure
         )
-        stage_inlet_pressure = suction_pressure
+        stage_inlet_pressure = self._suction_pressure
         for stage_number, stage in enumerate(self.stages):
             inlet_streams = [
                 self.fluid_factory.create_stream_from_standard_rate(
@@ -101,7 +105,7 @@ class CompressorTrainSimplified(CompressorTrainModel):
                     temperature_kelvin=stage.inlet_temperature_kelvin,
                     standard_rate_m3_per_day=inlet_rate,
                 )
-                for inlet_rate, inlet_pressure in zip(rate, stage_inlet_pressure)
+                for inlet_rate, inlet_pressure in zip(self._rate, stage_inlet_pressure)
             ]
             stage_outlet_pressure = np.multiply(stage_inlet_pressure, pressure_ratios_per_stage)
             if isinstance(stage, UndefinedCompressorStage):
@@ -314,13 +318,26 @@ class CompressorTrainSimplified(CompressorTrainModel):
 class CompressorTrainSimplifiedKnownStages(CompressorTrainSimplified):
     def __init__(
         self,
-        data_transfer_object: CompressorTrainSimplifiedWithKnownStages,
         fluid_factory: FluidFactoryInterface,
+        energy_usage_adjustment_constant: float,
+        energy_usage_adjustment_factor: float,
+        stages: list[CompressorStage],
+        calculate_max_rate: bool = False,
+        maximum_power: float | None = None,
     ):
         """See CompressorTrainSimplified for explanation of a compressor train."""
-        logger.debug(f"Creating CompressorTrainSimplifiedKnownStages with n_stages: {len(data_transfer_object.stages)}")
-        super().__init__(data_transfer_object, fluid_factory)
-        self.data_transfer_object = data_transfer_object
+        logger.debug(f"Creating CompressorTrainSimplifiedKnownStages with n_stages: {len(stages)}")
+        stages_mapped = [map_compressor_train_stage_to_domain(stage_dto) for stage_dto in stages]
+        super().__init__(
+            fluid_factory=fluid_factory,
+            energy_usage_adjustment_constant=energy_usage_adjustment_constant,
+            energy_usage_adjustment_factor=energy_usage_adjustment_factor,
+            stages=stages_mapped,
+            typ=EnergyModelType.COMPRESSOR_TRAIN_SIMPLIFIED_WITH_KNOWN_STAGES,
+            maximum_power=maximum_power,
+            pressure_control=None,  # Not relevant for simplified trains.
+            calculate_max_rate=calculate_max_rate,
+        )
 
     def define_undefined_stages(
         self,
@@ -512,12 +529,29 @@ class CompressorTrainSimplifiedUnknownStages(CompressorTrainSimplified):
 
     def __init__(
         self,
-        data_transfer_object: CompressorTrainSimplifiedWithUnknownStages,
         fluid_factory: FluidFactoryInterface,
+        energy_usage_adjustment_constant: float,
+        energy_usage_adjustment_factor: float,
+        stage: CompressorStage,
+        maximum_pressure_ratio_per_stage: float,
+        calculate_max_rate: bool = False,
+        maximum_power: float | None = None,
     ):
         logger.debug("Creating CompressorTrainSimplifiedUnknownStages")
-        super().__init__(data_transfer_object, fluid_factory)
-        self.data_transfer_object = data_transfer_object
+
+        super().__init__(
+            fluid_factory=fluid_factory,
+            energy_usage_adjustment_constant=energy_usage_adjustment_constant,
+            energy_usage_adjustment_factor=energy_usage_adjustment_factor,
+            stages=[],  # Stages are not defined yet
+            typ=EnergyModelType.COMPRESSOR_TRAIN_SIMPLIFIED_WITH_UNKNOWN_STAGES,
+            maximum_power=maximum_power,
+            pressure_control=None,  # Not relevant for simplified trains.
+            calculate_max_rate=calculate_max_rate,
+        )
+        self.stage = stage
+        self.maximum_pressure_ratio_per_stage = maximum_pressure_ratio_per_stage
+        self._validate_maximum_pressure_ratio_per_stage()
 
     def define_undefined_stages(
         self,
@@ -532,12 +566,10 @@ class CompressorTrainSimplifiedUnknownStages(CompressorTrainSimplified):
         maximum_pressure_ratio = max(pressure_ratios)
         number_of_compressors = self._calculate_number_of_compressors_needed(
             total_maximum_pressure_ratio=maximum_pressure_ratio,
-            compressor_maximum_pressure_ratio=self.data_transfer_object.maximum_pressure_ratio_per_stage,
+            compressor_maximum_pressure_ratio=self.maximum_pressure_ratio_per_stage,
         )
 
-        return [
-            map_compressor_train_stage_to_domain(self.data_transfer_object.stage) for _ in range(number_of_compressors)
-        ]
+        return [map_compressor_train_stage_to_domain(self.stage) for _ in range(number_of_compressors)]
 
     @staticmethod
     def _calculate_number_of_compressors_needed(
@@ -554,3 +586,10 @@ class CompressorTrainSimplifiedUnknownStages(CompressorTrainSimplified):
     ) -> float:
         """Max rate does not have a meaning when using unknown compressor stages."""
         return np.nan
+
+    def _validate_maximum_pressure_ratio_per_stage(self):
+        # TODO: Change validation to be > 1.0 instead of >= 0.0. Breaking.
+        if self.maximum_pressure_ratio_per_stage < 0:
+            msg = f"maximum_pressure_ratio_per_stage must be greater than or equal to 0. Invalid value: {self.maximum_pressure_ratio_per_stage}"
+
+            raise ProcessPressureRatioValidationException(message=str(msg))
