@@ -1,5 +1,6 @@
 from functools import partial
 
+from libecalc.common.energy_model_type import EnergyModelType
 from libecalc.common.errors.exceptions import EcalcError, IllegalStateException
 from libecalc.common.fixed_speed_pressure_control import FixedSpeedPressureControl
 from libecalc.common.logger import logger
@@ -18,7 +19,8 @@ from libecalc.domain.process.compressor.core.train.utils.numeric_methods import
     find_root,
     maximize_x_given_boolean_condition_function,
 )
-from libecalc.domain.process.compressor.dto import VariableSpeedCompressorTrain
+from libecalc.domain.process.compressor.core.utils import map_compressor_train_stage_to_domain
+from libecalc.domain.process.compressor.dto import CompressorStage
 from libecalc.domain.process.core.results.compressor import TargetPressureStatus
 from libecalc.domain.process.value_objects.fluid_stream.fluid_factory import FluidFactoryInterface
 
@@ -47,14 +49,26 @@ class VariableSpeedCompressorTrainCommonShaft(CompressorTrainModel):
 
     def __init__(
         self,
-        data_transfer_object: VariableSpeedCompressorTrain,
         fluid_factory: FluidFactoryInterface,
+        energy_usage_adjustment_constant: float,
+        energy_usage_adjustment_factor: float,
+        stages: list[CompressorStage],
+        pressure_control: FixedSpeedPressureControl | None = None,
+        calculate_max_rate: bool = False,
+        maximum_power: float | None = None,
     ):
-        logger.debug(
-            f"Creating VariableSpeedCompressorTrainCommonShaft with n_stages: {len(data_transfer_object.stages)}"
+        logger.debug(f"Creating VariableSpeedCompressorTrainCommonShaft with n_stages: {len(stages)}")
+        mapped_stages = [map_compressor_train_stage_to_domain(stage_dto) for stage_dto in stages]
+        super().__init__(
+            fluid_factory=fluid_factory,
+            energy_usage_adjustment_constant=energy_usage_adjustment_constant,
+            energy_usage_adjustment_factor=energy_usage_adjustment_factor,
+            stages=mapped_stages,
+            typ=EnergyModelType.VARIABLE_SPEED_COMPRESSOR_TRAIN_COMMON_SHAFT,
+            maximum_power=maximum_power,
+            pressure_control=pressure_control,
+            calculate_max_rate=calculate_max_rate,
         )
-        super().__init__(data_transfer_object, fluid_factory)
-        self.data_transfer_object = data_transfer_object
 
     def evaluate_given_constraints(
         self,
@@ -361,11 +375,11 @@ class VariableSpeedCompressorTrainCommonShaft(CompressorTrainModel):
 
         # Solution 3: If solution not found along max speed curve, and pressure control is downstream choke, we should
         # run at max_mass_rate, but using the defined pressure control.
-        elif self.data_transfer_object.pressure_control == FixedSpeedPressureControl.DOWNSTREAM_CHOKE:
+        elif self.pressure_control == FixedSpeedPressureControl.DOWNSTREAM_CHOKE:
             rate_to_return = max_mass_rate_at_max_speed * (1 - RATE_CALCULATION_TOLERANCE)
 
         # if pressure control is upstream choke, we find the new maximum rate with the reduced inlet pressure
-        elif self.data_transfer_object.pressure_control == FixedSpeedPressureControl.UPSTREAM_CHOKE:
+        elif self.pressure_control == FixedSpeedPressureControl.UPSTREAM_CHOKE:
             rate_to_return = maximize_x_given_boolean_condition_function(
                 x_min=0,
                 x_max=max_mass_rate_at_max_speed_first_stage,
@@ -423,7 +437,8 @@ class VariableSpeedCompressorTrainCommonShaft(CompressorTrainModel):
 
         # Check that rate_to_return, suction_pressure and discharge_pressure does not require too much power.
         # If so, reduce rate such that power comes below maximum power
-        if not self.data_transfer_object.maximum_power:
+        maximum_power = self.maximum_power
+        if not maximum_power:
             result = self.fluid_factory.mass_rate_to_standard_rate(rate_to_return)
             return float(result)
         elif (
@@ -432,7 +447,7 @@ class VariableSpeedCompressorTrainCommonShaft(CompressorTrainModel):
                     new_rate=self.fluid_factory.mass_rate_to_standard_rate(rate_to_return),  # type: ignore[arg-type]
                 )
             ).power_megawatt
-            > self.data_transfer_object.maximum_power
+            > maximum_power
         ):
             # check if minimum_rate gives too high power consumption
             result_with_minimum_rate = self.evaluate_given_constraints(
@@ -440,11 +455,12 @@ class VariableSpeedCompressorTrainCommonShaft(CompressorTrainModel):
                     new_rate=EPSILON,
                 )
             )
-            if result_with_minimum_rate.power_megawatt > self.data_transfer_object.maximum_power:
+            if result_with_minimum_rate.power_megawatt > maximum_power:
                 return 0.0  # can't find solution
             else:
                 # iterate between rate with minimum power, and the previously found rate to return, to find the
                 # maximum rate that gives power consumption below maximum power
+
                 result = self.fluid_factory.mass_rate_to_standard_rate(
                     find_root(
                         lower_bound=result_with_minimum_rate.stage_results[0].mass_rate_asv_corrected_kg_per_hour,
@@ -454,7 +470,7 @@ class VariableSpeedCompressorTrainCommonShaft(CompressorTrainModel):
                                 new_rate=self.fluid_factory.mass_rate_to_standard_rate(x),  # type: ignore[arg-type]
                             )
                         ).power_megawatt
-                        - self.data_transfer_object.maximum_power * (1 - POWER_CALCULATION_TOLERANCE),
+                        - maximum_power * (1 - POWER_CALCULATION_TOLERANCE),
                         relative_convergence_tolerance=1e-3,
                         maximum_number_of_iterations=20,
                     )
