@@ -1,5 +1,9 @@
+import math
 from copy import deepcopy
 
+import numpy as np
+from numpy._typing import NDArray
+
 from libecalc.common.errors.exceptions import IllegalStateException
 from libecalc.common.fixed_speed_pressure_control import FixedSpeedPressureControl
 from libecalc.common.logger import logger
@@ -11,6 +15,7 @@ from libecalc.domain.process.compressor.core.train.utils.common import EPSILON
 from libecalc.domain.process.compressor.core.train.utils.numeric_methods import (
     maximize_x_given_boolean_condition_function,
 )
+from libecalc.domain.process.compressor.core.utils import map_compressor_train_stage_to_domain
 from libecalc.domain.process.compressor.dto import VariableSpeedCompressorTrainMultipleStreamsAndPressures
 from libecalc.domain.process.core.results.compressor import TargetPressureStatus
 from libecalc.domain.process.value_objects.fluid_stream import ProcessConditions, SimplifiedStreamMixing
@@ -61,7 +66,19 @@ class VariableSpeedCompressorTrainCommonShaftMultipleStreamsAndPressures(
             f"Creating {type(self).__name__} with\n"
             f"n_stages: {len(data_transfer_object.stages)} and n_streams: {len(streams)}"
         )
-        super().__init__(data_transfer_object=data_transfer_object, fluid_factory=fluid_factory)
+        stages = [map_compressor_train_stage_to_domain(stage_dto) for stage_dto in data_transfer_object.stages]
+        super().__init__(
+            fluid_factory=fluid_factory,
+            energy_usage_adjustment_constant=data_transfer_object.energy_usage_adjustment_constant,
+            energy_usage_adjustment_factor=data_transfer_object.energy_usage_adjustment_factor,
+            stages=stages,
+            typ=data_transfer_object.typ,
+            maximum_power=data_transfer_object.maximum_power,
+            pressure_control=data_transfer_object.pressure_control,
+            calculate_max_rate=data_transfer_object.calculate_max_rate,
+            stage_number_interstage_pressure=data_transfer_object.stage_number_interstage_pressure,
+        )
+        self.data_transfer_object = data_transfer_object
         self.streams = streams
         self.number_of_compressor_streams = len(self.streams)
 
@@ -83,6 +100,25 @@ class VariableSpeedCompressorTrainCommonShaftMultipleStreamsAndPressures(
             else:
                 self.outlet_stream_connected_to_stage[stream.connected_to_stage_no].append(i)
 
+    def set_evaluation_input(
+        self,
+        rate: NDArray[np.float64],
+        suction_pressure: NDArray[np.float64] | None,
+        discharge_pressure: NDArray[np.float64] | None,
+        intermediate_pressure: NDArray[np.float64] | None = None,
+    ):
+        has_interstage_pressure = any(stage.has_control_pressure for stage in self.data_transfer_object.stages)
+        if has_interstage_pressure and intermediate_pressure is None:
+            raise ValueError("Energy model requires interstage control pressure to be defined")
+        if not has_interstage_pressure and intermediate_pressure is not None:
+            raise ValueError("Energy model does not accept interstage control pressure to be defined")
+        super().set_evaluation_input(
+            rate=rate,
+            suction_pressure=suction_pressure,
+            discharge_pressure=discharge_pressure,
+            intermediate_pressure=intermediate_pressure,
+        )
+
     @staticmethod
     def _check_intermediate_pressure_stage_number_is_valid(
         _stage_number_intermediate_pressure: int,
@@ -533,13 +569,22 @@ class VariableSpeedCompressorTrainCommonShaftMultipleStreamsAndPressures(
             lower_bound_for_speed=self.minimum_speed,  # Only search for a solution within the bounds of the
             upper_bound_for_speed=self.maximum_speed,  # original, complete compressor train
         )
-        compressor_train_results_first_part_with_optimal_speed_result = (
-            compressor_train_first_part.calculate_compressor_train(
-                constraints=constraints_first_part.create_conditions_with_new_input(
-                    new_speed=compressor_train_first_part_optimal_speed,
+        if math.isclose(compressor_train_first_part_optimal_speed, self.minimum_speed, rel_tol=EPSILON):
+            compressor_train_results_first_part_with_optimal_speed_result = (
+                compressor_train_first_part.evaluate_with_pressure_control_given_constraints(
+                    constraints=constraints_first_part.create_conditions_with_new_input(
+                        new_speed=compressor_train_first_part_optimal_speed,
+                    )
+                )
+            )
+        else:
+            compressor_train_results_first_part_with_optimal_speed_result = (
+                compressor_train_first_part.calculate_compressor_train(
+                    constraints=constraints_first_part.create_conditions_with_new_input(
+                        new_speed=compressor_train_first_part_optimal_speed,
+                    )
                 )
             )
-        )
 
         if self.data_transfer_object.calculate_max_rate:
             max_standard_rate_per_stream = [
@@ -582,13 +627,23 @@ class VariableSpeedCompressorTrainCommonShaftMultipleStreamsAndPressures(
             lower_bound_for_speed=self.minimum_speed,
             upper_bound_for_speed=self.maximum_speed,
         )
-        compressor_train_results_last_part_with_optimal_speed_result = (
-            compressor_train_last_part.calculate_compressor_train(
-                constraints=constraints_last_part.create_conditions_with_new_input(
-                    new_speed=compressor_train_last_part_optimal_speed,
+
+        if math.isclose(compressor_train_last_part_optimal_speed, self.minimum_speed, rel_tol=EPSILON):
+            compressor_train_results_last_part_with_optimal_speed_result = (
+                compressor_train_last_part.evaluate_with_pressure_control_given_constraints(
+                    constraints=constraints_last_part.create_conditions_with_new_input(
+                        new_speed=compressor_train_last_part_optimal_speed,
+                    )
+                )
+            )
+        else:
+            compressor_train_results_last_part_with_optimal_speed_result = (
+                compressor_train_last_part.calculate_compressor_train(
+                    constraints=constraints_last_part.create_conditions_with_new_input(
+                        new_speed=compressor_train_last_part_optimal_speed,
+                    )
                 )
             )
-        )
 
         if self.data_transfer_object.calculate_max_rate:
             for stream_index, _ in enumerate(compressor_train_last_part.streams):
