@@ -13,12 +13,10 @@ from libecalc.common.component_info.compressor import CompressorPressureType
 from libecalc.common.component_type import ComponentType
 from libecalc.common.decorators.feature_flags import Feature
 from libecalc.common.errors.exceptions import ProgrammingError
-from libecalc.common.list.list_utils import array_to_list
 from libecalc.common.temporal_model import TemporalModel
 from libecalc.common.time_utils import Period, Periods
 from libecalc.common.units import Unit
 from libecalc.common.utils.rates import RateType, TimeSeriesBoolean, TimeSeriesFloat, TimeSeriesInt, TimeSeriesRate
-from libecalc.common.variables import ExpressionEvaluator
 from libecalc.core.result.emission import EmissionResult
 from libecalc.core.result.results import EcalcModelResult
 from libecalc.domain.infrastructure.energy_components.asset.asset import Asset
@@ -34,7 +32,6 @@ from libecalc.domain.infrastructure.energy_components.legacy_consumer.system.con
 )
 from libecalc.domain.time_series_pressure import TimeSeriesPressure
 from libecalc.dto import node_info
-from libecalc.expression import Expression
 from libecalc.presentation.json_result.aggregators import aggregate_emissions, aggregate_is_valid
 from libecalc.presentation.json_result.result import ComponentResult as JsonResultComponentResult
 from libecalc.presentation.json_result.result.emission import EmissionResult as JsonResultEmissionResult
@@ -43,15 +40,12 @@ from libecalc.presentation.json_result.result.results import (
     AssetResult,
     CompressorModelResult,
     CompressorModelStageResult,
-    CompressorOperationalSettingResult,
     CompressorStreamConditionResult,
     ConsumerSystemResult,
     GenericConsumerResult,
     GenericModelResult,
     InstallationResult,
-    OperationalSettingResult,
     PumpModelResult,
-    PumpOperationalSettingResult,
     TurbineModelResult,
 )
 
@@ -123,7 +117,6 @@ class ModelResultHelper:
                     if consumer_node_info.component_type == ComponentType.COMPRESSOR_SYSTEM
                     else None,
                     model_periods=model.periods,
-                    expression_evaluator=graph_result.variables_map,
                 ).for_period(period)
                 requested_outlet_pressure = CompressorHelper.get_requested_compressor_pressures(
                     energy_usage_model=energy_usage_model,
@@ -133,7 +126,6 @@ class ModelResultHelper:
                     if consumer_node_info.component_type == ComponentType.COMPRESSOR_SYSTEM
                     else None,
                     model_periods=model.periods,
-                    expression_evaluator=graph_result.variables_map,
                 ).for_period(period)
 
             model_stage_results = CompressorHelper.process_stage_results(model, regularity)  # type: ignore[arg-type]
@@ -628,10 +620,7 @@ class ComponentResultHelper:
             id=consumer_result.component_result.id,
             is_valid=consumer_result.component_result.is_valid,
             operational_settings_used=consumer_result.component_result.operational_settings_used,
-            operational_settings_results=OperationalSettingHelper.process_operational_settings_results(
-                operational_settings_results=consumer_result.component_result.operational_settings_results,
-                regularity=regularity,
-            ),
+            operational_settings_results=None,
         )
 
 
@@ -652,7 +641,6 @@ class CompressorHelper:
         pressure_type: CompressorPressureType,
         name: str,
         model_periods: Periods,
-        expression_evaluator: ExpressionEvaluator,
         operational_settings_used: TimeSeriesInt | None = None,
     ) -> TimeSeriesFloat:
         """Get temporal model for compressor inlet- and outlet pressures.
@@ -670,8 +658,8 @@ class CompressorHelper:
         Returns:
             TemporalModel[Expression]: Temporal model with pressures as expressions.
         """
-
-        evaluated_temporal_energy_usage_models = {}
+        periods = []
+        values = []
         for period, model in energy_usage_model.items():
             # Loop periods in temporal model, to find correct operational settings used:
             periods_in_period = period.get_periods(model_periods)
@@ -682,7 +670,6 @@ class CompressorHelper:
                             period=_period,
                             operational_settings_used=operational_settings_used,  # type: ignore[arg-type]
                         )
-
                         operational_setting = model.operational_settings[operational_setting_used_id]
 
                         # Find correct compressor in case of different pressures for different components in system:
@@ -694,16 +681,19 @@ class CompressorHelper:
                             pressures = operational_setting.suction_pressures[compressor_nr]
                         else:
                             pressures = operational_setting.discharge_pressures[compressor_nr]
-
-                        if pressures is None:
-                            pressures = Expression.setup_from_expression(value=math.nan)
-
-                        evaluated_temporal_energy_usage_models[_period] = pressures
-        temporal_pressure_model = TemporalModel(evaluated_temporal_energy_usage_models)
-        pressure_values = expression_evaluator.evaluate(temporal_pressure_model)
+                        if pressures is not None:
+                            try:
+                                idx = pressures.get_periods().periods.index(_period)
+                                value = float(pressures.get_values()[idx])
+                            except ValueError:
+                                value = math.nan
+                        else:
+                            value = math.nan
+                        periods.append(_period)
+                        values.append(value)
         return TimeSeriesFloat(
-            periods=expression_evaluator.get_periods(),
-            values=array_to_list(pressure_values),
+            periods=Periods(periods),
+            values=values,
             unit=Unit.BARA,
         )
 
@@ -1259,65 +1249,6 @@ class OperationalSettingHelper:
 
         return operational_setting_id - 1
 
-    @staticmethod
-    def process_operational_settings_results(
-        operational_settings_results: dict[str, list[Any]], regularity: TimeSeriesFloat
-    ) -> dict[str, list[Any]]:
-        processed_results = {}
-        for key, models in operational_settings_results.items():
-            processed_models: list[OperationalSettingResult] = []
-            for model in models:
-                if model.component_type == ComponentType.PUMP:
-                    result = PumpOperationalSettingResult(
-                        name=model.name,
-                        periods=model.periods,
-                        is_valid=model.is_valid,
-                        energy_usage=TimeSeriesHelper.initialize_timeseries(
-                            model.periods, model.energy_usage.values, model.energy_usage.unit
-                        ),
-                        power=TimeSeriesHelper.initialize_timeseries(
-                            model.periods, model.power.values, model.power.unit
-                        ),
-                        inlet_liquid_rate_m3_per_day=model.inlet_liquid_rate_m3_per_day,
-                        inlet_pressure_bar=model.inlet_pressure_bar,
-                        outlet_pressure_bar=model.outlet_pressure_bar,
-                        operational_head=model.operational_head,
-                    )
-                    processed_models.append(result)
-                elif model.component_type == ComponentType.COMPRESSOR:
-                    model_stage_results = CompressorHelper.process_stage_results(model, regularity)
-                    turbine_result = ModelResultHelper.process_turbine_result(model, regularity)
-
-                    inlet_stream_condition = CompressorHelper.process_inlet_stream_condition(
-                        model.periods, model.inlet_stream_condition, regularity
-                    )
-
-                    outlet_stream_condition = CompressorHelper.process_outlet_stream_condition(
-                        model.periods, model.outlet_stream_condition, regularity
-                    )
-                    result = CompressorOperationalSettingResult(
-                        name=model.name,
-                        periods=model.periods,
-                        is_valid=model.is_valid,
-                        energy_usage=TimeSeriesHelper.initialize_timeseries(
-                            model.periods, model.energy_usage.values, model.energy_usage.unit
-                        ),
-                        power=TimeSeriesHelper.initialize_timeseries(
-                            model.periods, model.power.values, model.power.unit
-                        ),
-                        failure_status=model.failure_status,
-                        max_standard_rate=model.max_standard_rate,
-                        rate_sm3_day=model.rate_sm3_day,
-                        inlet_stream_condition=inlet_stream_condition,
-                        outlet_stream_condition=outlet_stream_condition,
-                        stage_results=model_stage_results,
-                        turbine_result=turbine_result if turbine_result else None,
-                    )
-                    processed_models.append(result)
-
-            processed_results[key] = processed_models
-        return processed_results
-
 
 def get_asset_result(graph_result: GraphResult) -> libecalc.presentation.json_result.result.results.EcalcModelResult:
     asset_id = graph_result.graph.root
