@@ -1,8 +1,6 @@
 from typing import assert_never
 from uuid import UUID, uuid4
 
-from pydantic import ValidationError
-
 from libecalc.common.component_type import ComponentType
 from libecalc.common.consumer_type import ConsumerType
 from libecalc.common.consumption_type import ConsumptionType
@@ -10,11 +8,8 @@ from libecalc.common.energy_model_type import EnergyModelType
 from libecalc.common.temporal_model import InvalidTemporalModel, TemporalModel
 from libecalc.common.time_utils import Period, define_time_model_for_period
 from libecalc.common.variables import ExpressionEvaluator
-from libecalc.domain.component_validation_error import (
-    ComponentValidationException,
-    ModelValidationError,
-)
-from libecalc.domain.hydrocarbon_export import HydrocarbonExport, InvalidHydrocarbonExport
+from libecalc.domain.component_validation_error import DomainValidationException
+from libecalc.domain.hydrocarbon_export import HydrocarbonExport
 from libecalc.domain.infrastructure.emitters.venting_emitter import (
     DirectVentingEmitter,
     EmissionRate,
@@ -35,11 +30,15 @@ from libecalc.domain.infrastructure.energy_components.generator_set.generator_se
 )
 from libecalc.domain.infrastructure.energy_components.installation.installation import InstallationComponent
 from libecalc.domain.infrastructure.path_id import PathID
-from libecalc.domain.regularity import InvalidRegularity, Regularity
+from libecalc.domain.regularity import Regularity
 from libecalc.dto import FuelType
-from libecalc.dto.utils.validators import convert_expression
 from libecalc.expression.expression import InvalidExpressionError
+from libecalc.presentation.yaml.domain.expression_time_series_cable_loss import ExpressionTimeSeriesCableLoss
+from libecalc.presentation.yaml.domain.expression_time_series_max_usage_from_shore import (
+    ExpressionTimeSeriesMaxUsageFromShore,
+)
 from libecalc.presentation.yaml.domain.reference_service import InvalidReferenceException, ReferenceService
+from libecalc.presentation.yaml.domain.time_series_expression import TimeSeriesExpression
 from libecalc.presentation.yaml.domain.yaml_component import YamlComponent
 from libecalc.presentation.yaml.mappers.consumer_function_mapper import (
     ConsumerFunctionMapper,
@@ -47,7 +46,8 @@ from libecalc.presentation.yaml.mappers.consumer_function_mapper import (
 )
 from libecalc.presentation.yaml.mappers.yaml_mapping_context import MappingContext
 from libecalc.presentation.yaml.mappers.yaml_path import YamlPath
-from libecalc.presentation.yaml.validation_errors import DtoValidationError, Location
+from libecalc.presentation.yaml.model_validation_exception import ModelValidationException
+from libecalc.presentation.yaml.validation_errors import Location, ModelValidationError
 from libecalc.presentation.yaml.yaml_models.yaml_model import YamlValidator
 from libecalc.presentation.yaml.yaml_types.components.legacy.energy_usage_model import (
     YamlElectricityEnergyUsageModel,
@@ -221,16 +221,16 @@ class ConsumerMapper:
                 file_context=file_context,
             )
 
-        def create_error_from_yaml_path(
+        def create_error(
             message: str,
-            specific_path: YamlPath,
+            specific_path: YamlPath = None,
         ):
-            file_context = configuration.get_file_context(specific_path.keys) or configuration.get_file_context(
-                yaml_path.keys
-            )
+            yaml_path_to_use = specific_path if specific_path is not None else yaml_path
+            file_context = configuration.get_file_context(yaml_path_to_use.keys)
+
             return ModelValidationError(
                 message=message,
-                location=get_location_from_yaml_path(specific_path, mapping_context=mapping_context),
+                location=get_location_from_yaml_path(yaml_path_to_use, mapping_context=mapping_context),
                 name=data.name,
                 file_context=file_context,
             )
@@ -244,18 +244,20 @@ class ConsumerMapper:
         except InvalidEnergyUsageModelException as e:
             energy_usage_model_yaml_path = yaml_path.append("ENERGY_USAGE_MODEL")
             specific_model_path = energy_usage_model_yaml_path.append(e.period.start)
-            raise ComponentValidationException(
+            raise ModelValidationException(
                 errors=[
-                    create_error_from_yaml_path(
+                    create_error(
                         message=e.message,
                         specific_path=specific_model_path,
                     )
                 ]
             ) from e
         except InvalidTemporalModel as e:
-            raise ComponentValidationException(
+            raise ModelValidationException(
                 errors=[create_error_from_key(message=str(e), key="ENERGY_USAGE_MODEL")]
             ) from e
+        except DomainValidationException as e:
+            raise ModelValidationException(errors=[create_error_from_key(str(e), key="ENERGY_USAGE_MODEL")]) from e
 
         if consumes == ConsumptionType.FUEL:
             consumer_fuel = data.fuel
@@ -271,30 +273,41 @@ class ConsumerMapper:
                         yaml_path=fuel_yaml_path,
                     )
                 )
-            except (InvalidReferenceException, MissingFuelReference, InvalidTemporalModel) as e:
-                raise ComponentValidationException(
-                    errors=[create_error_from_yaml_path(message=str(e), specific_path=fuel_yaml_path)]
+            except (
+                InvalidReferenceException,
+                MissingFuelReference,
+                InvalidTemporalModel,
+                DomainValidationException,
+            ) as e:  # TODO: Should all these also be DomainValidationException? Do we need 'domain' or can we just have SingleValidationError (or ValidationValueError which already exists), i.e. two validation errors, one for a single error and one for Model where we expect several errors and some context.
+                raise ModelValidationException(
+                    errors=[create_error(message=str(e), specific_path=fuel_yaml_path)]
                 ) from e
 
-            return FuelConsumerComponent(
-                id=id,
-                path_id=path_id,
-                regularity=regularity,
-                fuel=fuel,
-                energy_usage_model=energy_usage_model,
-                component_type=_get_component_type(data.energy_usage_model),
-                expression_evaluator=expression_evaluator,
-            )
+            try:
+                return FuelConsumerComponent(
+                    id=id,
+                    path_id=path_id,
+                    regularity=regularity,
+                    fuel=fuel,
+                    energy_usage_model=energy_usage_model,
+                    component_type=_get_component_type(data.energy_usage_model),
+                    expression_evaluator=expression_evaluator,
+                )
+            except DomainValidationException as e:
+                raise ModelValidationException(errors=[create_error(message=str(e))]) from e
         else:
-            return ElectricityConsumer(
-                id=id,
-                path_id=path_id,
-                regularity=regularity,
-                energy_usage_model=energy_usage_model,
-                component_type=_get_component_type(data.energy_usage_model),
-                consumes=consumes,
-                expression_evaluator=expression_evaluator,
-            )
+            try:
+                return ElectricityConsumer(
+                    id=id,
+                    path_id=path_id,
+                    regularity=regularity,
+                    energy_usage_model=energy_usage_model,
+                    component_type=_get_component_type(data.energy_usage_model),
+                    consumes=consumes,
+                    expression_evaluator=expression_evaluator,
+                )
+            except DomainValidationException as e:
+                raise ModelValidationException(errors=[create_error(message=str(e))]) from e
 
 
 class GeneratorSetMapper:
@@ -315,11 +328,15 @@ class GeneratorSetMapper:
         mapping_context: MappingContext,
         default_fuel: str | None = None,
     ) -> GeneratorSetEnergyComponent | None:
-        def create_error(message: str, key: str) -> ModelValidationError:
-            file_context = configuration.get_file_context(yaml_path.keys)
+        def create_error(message: str, key: str | None = None) -> ModelValidationError:
+            if key is None:
+                yaml_path_to_use = yaml_path
+            else:
+                yaml_path_to_use = yaml_path.append(key)
+            file_context = configuration.get_file_context(yaml_path_to_use.keys)
             return ModelValidationError(
                 message=message,
-                location=get_location_from_yaml_path(yaml_path.append(key), mapping_context=mapping_context),
+                location=get_location_from_yaml_path(yaml_path_to_use, mapping_context=mapping_context),
                 name=data.name,
                 file_context=file_context,
             )
@@ -336,8 +353,8 @@ class GeneratorSetMapper:
                     yaml_path=fuel_yaml_path,
                 )
             )
-        except (InvalidReferenceException, MissingFuelReference, InvalidTemporalModel) as e:
-            raise ComponentValidationException(errors=[create_error(str(e), key="fuel")]) from e
+        except (InvalidReferenceException, MissingFuelReference, InvalidTemporalModel, DomainValidationException) as e:
+            raise ModelValidationException(errors=[create_error(str(e), key="fuel")]) from e
 
         generator_set_model_data = define_time_model_for_period(
             data.electricity2fuel, target_period=self._target_period
@@ -350,10 +367,8 @@ class GeneratorSetMapper:
                     for start_time, model_reference in generator_set_model_data.items()
                 }
             )
-        except InvalidReferenceException as e:
-            raise ComponentValidationException(errors=[create_error(str(e), key="ELECTRICITY2FUEL")]) from e
-        except InvalidTemporalModel as e:
-            raise ComponentValidationException(errors=[create_error(str(e), key="ELECTRICITY2FUEL")]) from e
+        except (InvalidReferenceException, InvalidTemporalModel, DomainValidationException) as e:
+            raise ModelValidationException(errors=[create_error(str(e), key="ELECTRICITY2FUEL")]) from e
 
         consumers_yaml_path = yaml_path.append("CONSUMERS")
         consumers: list[ElectricityConsumer] = []
@@ -390,27 +405,48 @@ class GeneratorSetMapper:
             consumers.append(parsed_consumer)
 
         try:
-            cable_loss = convert_expression(data.cable_loss)
-        except InvalidExpressionError as e:
-            raise ComponentValidationException(errors=[create_error(str(e), key="CABLE_LOSS")]) from e
+            category_model = TemporalModel.create(data.category, target_period=self._target_period)
+            if data.cable_loss and category_model is not None:
+                cable_loss = ExpressionTimeSeriesCableLoss(
+                    time_series_expression=TimeSeriesExpression(
+                        expression=data.cable_loss, expression_evaluator=expression_evaluator
+                    ),
+                    category=category_model,
+                )
+            else:
+                cable_loss = None
+
+        except (InvalidExpressionError, DomainValidationException) as e:
+            raise ModelValidationException(errors=[create_error(str(e), key="CABLE_LOSS")]) from e
 
         try:
-            max_usage_from_shore = convert_expression(data.max_usage_from_shore)
-        except InvalidExpressionError as e:
-            raise ComponentValidationException(errors=[create_error(str(e), key="MAX_USAGE_FROM_SHORE")]) from e
+            max_usage_from_shore = (
+                ExpressionTimeSeriesMaxUsageFromShore(
+                    TimeSeriesExpression(
+                        expression=data.max_usage_from_shore, expression_evaluator=expression_evaluator
+                    )
+                )
+                if data.max_usage_from_shore
+                else None
+            )
+        except (InvalidExpressionError, DomainValidationException) as e:
+            raise ModelValidationException(errors=[create_error(str(e), key="MAX_USAGE_FROM_SHORE")]) from e
 
-        return GeneratorSetEnergyComponent(
-            id=id,
-            path_id=path_id,
-            fuel=fuel,
-            regularity=regularity,
-            generator_set_model=generator_set_model,
-            consumers=consumers,
-            cable_loss=cable_loss,  # type: ignore[arg-type]
-            max_usage_from_shore=max_usage_from_shore,  # type: ignore[arg-type]
-            component_type=ComponentType.GENERATOR_SET,
-            expression_evaluator=expression_evaluator,
-        )
+        try:
+            return GeneratorSetEnergyComponent(
+                id=id,
+                path_id=path_id,
+                fuel=fuel,
+                regularity=regularity,
+                generator_set_model=generator_set_model,
+                consumers=consumers,
+                cable_loss=cable_loss,
+                max_usage_from_shore=max_usage_from_shore,
+                component_type=ComponentType.GENERATOR_SET,
+                expression_evaluator=expression_evaluator,
+            )
+        except DomainValidationException as e:
+            raise ModelValidationException(errors=[create_error(str(e), key="MAX_USAGE_FROM_SHORE")]) from e
 
 
 class InstallationMapper:
@@ -487,8 +523,8 @@ class InstallationMapper:
                 )
             else:
                 return assert_never(data)
-        except InvalidExpressionError as e:
-            raise ComponentValidationException(errors=[create_error(message=str(e))]) from e
+        except (InvalidExpressionError, DomainValidationException) as e:
+            raise ModelValidationException(errors=[create_error(message=str(e))]) from e
 
     def from_yaml_to_domain(
         self,
@@ -500,11 +536,15 @@ class InstallationMapper:
         yaml_path: YamlPath,
         mapping_context: MappingContext,
     ) -> InstallationComponent:
-        def create_error(message: str, key: str) -> ModelValidationError:
-            file_context = configuration.get_file_context(yaml_path.keys)
+        def create_error(message: str, key: str | None = None) -> ModelValidationError:
+            if key is None:
+                yaml_path_to_use = yaml_path
+            else:
+                yaml_path_to_use = yaml_path.append(key)
+            file_context = configuration.get_file_context(yaml_path_to_use.keys)
             return ModelValidationError(
                 message=message,
-                location=get_location_from_yaml_path(yaml_path.append(key), mapping_context=mapping_context),
+                location=get_location_from_yaml_path(yaml_path_to_use, mapping_context=mapping_context),
                 name=data.name,
                 file_context=file_context,
             )
@@ -517,8 +557,8 @@ class InstallationMapper:
                 target_period=self._target_period,
                 expression_evaluator=expression_evaluator,
             )
-        except InvalidRegularity as e:
-            raise ComponentValidationException(errors=[create_error(message=e.message, key="regularity")]) from e
+        except DomainValidationException as e:
+            raise ModelValidationException(errors=[create_error(message=e.message, key="regularity")]) from e
 
         try:
             hydrocarbon_export = HydrocarbonExport(
@@ -527,8 +567,8 @@ class InstallationMapper:
                 regularity=regularity,
                 target_period=self._target_period,
             )
-        except InvalidHydrocarbonExport as e:
-            raise ComponentValidationException(errors=[create_error(message=e.message, key="HCEXPORT")]) from e
+        except DomainValidationException as e:
+            raise ModelValidationException(errors=[create_error(message=e.message, key="HCEXPORT")]) from e
 
         generator_sets_yaml_path = yaml_path.append("GENERATORSETS")
         generator_sets = []
@@ -618,15 +658,18 @@ class InstallationMapper:
             )
             venting_emitters.append(parsed_venting_emitter)
 
-        return InstallationComponent(
-            id=id,
-            path_id=path_id,
-            regularity=regularity,
-            hydrocarbon_export=hydrocarbon_export,
-            fuel_consumers=[*generator_sets, *fuel_consumers],  # type: ignore[list-item]
-            venting_emitters=venting_emitters,  # type: ignore[arg-type]
-            expression_evaluator=expression_evaluator,
-        )
+        try:
+            return InstallationComponent(
+                id=id,
+                path_id=path_id,
+                regularity=regularity,
+                hydrocarbon_export=hydrocarbon_export,
+                fuel_consumers=[*generator_sets, *fuel_consumers],  # type: ignore[list-item]
+                venting_emitters=venting_emitters,  # type: ignore[arg-type]
+                expression_evaluator=expression_evaluator,
+            )
+        except DomainValidationException as e:
+            raise ModelValidationException(errors=[create_error(str(e))]) from e
 
 
 class EcalcModelMapper:
@@ -676,5 +719,13 @@ class EcalcModelMapper:
                 installations=installations,
             )
             return ecalc_model
-        except ValidationError as e:
-            raise DtoValidationError(data=None, validation_error=e) from e
+        except DomainValidationException as e:
+            raise ModelValidationException(
+                errors=[
+                    ModelValidationError(
+                        message=str(e),
+                        location=Location(keys=""),
+                        file_context=configuration.get_file_context(()),
+                    )
+                ]
+            ) from e
