@@ -1,14 +1,13 @@
 import logging
 from typing import Protocol, assert_never
 
-from libecalc.common.chart_type import ChartType
 from libecalc.common.consumption_type import ConsumptionType
-from libecalc.common.energy_model_type import EnergyModelType
 from libecalc.common.energy_usage_type import EnergyUsageType
 from libecalc.common.temporal_model import TemporalModel
 from libecalc.common.time_utils import Period, define_time_model_for_period
 from libecalc.common.utils.rates import RateType
 from libecalc.common.variables import ExpressionEvaluator
+from libecalc.domain.component_validation_error import DomainValidationException
 from libecalc.domain.infrastructure.energy_components.legacy_consumer.consumer_function import ConsumerFunction
 from libecalc.domain.infrastructure.energy_components.legacy_consumer.consumer_function.compressor_consumer_function import (
     CompressorConsumerFunction,
@@ -32,19 +31,9 @@ from libecalc.domain.infrastructure.energy_components.legacy_consumer.system.typ
 from libecalc.domain.infrastructure.energy_components.legacy_consumer.tabulated import (
     TabularConsumerFunction,
 )
-from libecalc.domain.process.compressor.core import create_compressor_model
-from libecalc.domain.process.compressor.dto import (
-    CompressorTrainSimplifiedWithKnownStages,
-    CompressorTrainSimplifiedWithUnknownStages,
-    CompressorWithTurbine,
-    VariableSpeedCompressorTrainMultipleStreamsAndPressures,
-)
-from libecalc.domain.process.compressor.dto.model_types import CompressorModelTypes
-from libecalc.domain.process.pump.factory import create_pump_model
 from libecalc.domain.regularity import Regularity
 from libecalc.domain.time_series_flow_rate import TimeSeriesFlowRate
 from libecalc.domain.time_series_variable import TimeSeriesVariable
-from libecalc.dto.utils.validators import convert_expression, convert_expressions
 from libecalc.expression import Expression
 from libecalc.expression.expression import InvalidExpressionError
 from libecalc.presentation.yaml.domain.expression_time_series_flow_rate import ExpressionTimeSeriesFlowRate
@@ -57,7 +46,6 @@ from libecalc.presentation.yaml.domain.expression_time_series_pressure import Ex
 from libecalc.presentation.yaml.domain.expression_time_series_variable import ExpressionTimeSeriesVariable
 from libecalc.presentation.yaml.domain.reference_service import ReferenceService
 from libecalc.presentation.yaml.domain.time_series_expression import TimeSeriesExpression
-from libecalc.presentation.yaml.yaml_keywords import EcalcYamlKeywords
 from libecalc.presentation.yaml.yaml_types.components.legacy.energy_usage_model import (
     YamlElectricityEnergyUsageModel,
     YamlEnergyUsageModelCompressor,
@@ -111,57 +99,6 @@ def _all_equal(items: set) -> bool:
     return len(items) <= 1
 
 
-def _get_compressor_train_energy_usage_type(
-    compressor_train: CompressorModelTypes,
-) -> EnergyUsageType:
-    typ = compressor_train.typ
-
-    if typ == EnergyModelType.COMPRESSOR_SAMPLED:
-        energy_usage_type = compressor_train.energy_usage_type
-    elif typ in (
-        EnergyModelType.COMPRESSOR_TRAIN_SIMPLIFIED_WITH_KNOWN_STAGES,
-        EnergyModelType.COMPRESSOR_TRAIN_SIMPLIFIED_WITH_UNKNOWN_STAGES,
-        EnergyModelType.VARIABLE_SPEED_COMPRESSOR_TRAIN_COMMON_SHAFT,
-    ):
-        energy_usage_type = EnergyUsageType.POWER
-    elif typ == EnergyModelType.COMPRESSOR_WITH_TURBINE:
-        energy_usage_type = EnergyUsageType.FUEL
-    elif (
-        typ == EnergyModelType.VARIABLE_SPEED_COMPRESSOR_TRAIN_MULTIPLE_STREAMS_AND_PRESSURES
-        or typ == EnergyModelType.SINGLE_SPEED_COMPRESSOR_TRAIN_COMMON_SHAFT
-    ):
-        energy_usage_type = EnergyUsageType.POWER
-    else:
-        raise ValueError(f"Invalid compressor model {compressor_train}")
-
-    return energy_usage_type
-
-
-def check_for_generic_from_input_compressor_chart_in_simplified_train_compressor_system(
-    compressor_train: CompressorModelTypes,
-    name: str,
-):
-    if isinstance(compressor_train, CompressorTrainSimplifiedWithKnownStages):
-        for i, stage in enumerate(compressor_train.stages):
-            if stage.compressor_chart.typ == ChartType.GENERIC_FROM_INPUT:
-                logger.warning(
-                    f"Stage number {i + 1} in {name} uses GENERIC_FROM_INPUT. "
-                    f"Beware that when splitting rates on several compressor trains in a compressor system, "
-                    f"the rate input used to generate a specific compressor chart will also change. Consider"
-                    f" to define a design point yourself instead of letting an algorithm find one based on"
-                    f" changing rates!"
-                )
-    elif isinstance(compressor_train, CompressorTrainSimplifiedWithUnknownStages):
-        if compressor_train.stage.compressor_chart.typ == ChartType.GENERIC_FROM_INPUT:
-            logger.warning(
-                f"Compressor chart in {name} uses GENERIC_FROM_INPUT. "
-                f"Beware that when splitting rates on several compressor trains in a compressor system, "
-                f"the rate input used to generate a specific compressor chart will also change. Consider"
-                f" to define a design point yourself instead of letting an algorithm find one based on"
-                f" changing rates!"
-            )
-
-
 class InvalidEnergyUsageModelException(Exception):
     def __init__(self, period: Period, model: YamlFuelEnergyUsageModel | YamlElectricityEnergyUsageModel, message: str):
         self.period = period
@@ -215,7 +152,7 @@ class ConsumerFunctionMapper:
         period_regularity, period_evaluator = self._period_subsets[period]
 
         power_loss_factor_expression = TimeSeriesExpression(
-            expressions=model.power_loss_factor, expression_evaluator=period_evaluator
+            expression=model.power_loss_factor, expression_evaluator=period_evaluator
         )
         power_loss_factor = ExpressionTimeSeriesPowerLossFactor(time_series_expression=power_loss_factor_expression)
 
@@ -225,7 +162,7 @@ class ConsumerFunctionMapper:
             if consumes != ConsumptionType.FUEL:
                 raise InvalidConsumptionType(actual=ConsumptionType.FUEL, expected=consumes)
             fuel_rate_expression = TimeSeriesExpression(
-                expressions=model.fuel_rate, expression_evaluator=period_evaluator, condition=_map_condition(model)
+                expression=model.fuel_rate, expression_evaluator=period_evaluator, condition=_map_condition(model)
             )
             fuel_rate = ExpressionTimeSeriesFlowRate(
                 time_series_expression=fuel_rate_expression,
@@ -244,7 +181,7 @@ class ConsumerFunctionMapper:
                 raise InvalidConsumptionType(actual=ConsumptionType.ELECTRICITY, expected=consumes)
 
             load_expression = TimeSeriesExpression(
-                expressions=model.load, expression_evaluator=period_evaluator, condition=_map_condition(model)
+                expression=model.load, expression_evaluator=period_evaluator, condition=_map_condition(model)
             )
             load = ExpressionTimeSeriesPower(
                 time_series_expression=load_expression,
@@ -271,7 +208,7 @@ class ConsumerFunctionMapper:
             raise InvalidConsumptionType(actual=energy_usage_type_as_consumption_type, expected=consumes)
 
         power_loss_factor_expression = TimeSeriesExpression(
-            expressions=model.power_loss_factor, expression_evaluator=period_evaluator
+            expression=model.power_loss_factor, expression_evaluator=period_evaluator
         )
         power_loss_factor = ExpressionTimeSeriesPowerLossFactor(time_series_expression=power_loss_factor_expression)
 
@@ -279,7 +216,7 @@ class ConsumerFunctionMapper:
             ExpressionTimeSeriesVariable(
                 name=variable.name,
                 time_series_expression=TimeSeriesExpression(
-                    expressions=variable.expression,
+                    expression=variable.expression,
                     expression_evaluator=period_evaluator,
                     condition=_map_condition(model),
                 ),
@@ -301,18 +238,18 @@ class ConsumerFunctionMapper:
     def _map_pump(
         self, model: YamlEnergyUsageModelPump, consumes: ConsumptionType, period: Period
     ) -> PumpConsumerFunction:
-        energy_model = self.__references.get_pump_model(model.energy_function)
+        pump_model = self.__references.get_pump_model(model.energy_function)
         period_regularity, period_evaluator = self._period_subsets[period]
         if consumes != ConsumptionType.ELECTRICITY:
             raise InvalidConsumptionType(actual=ConsumptionType.ELECTRICITY, expected=consumes)
 
         power_loss_factor_expression = TimeSeriesExpression(
-            expressions=model.power_loss_factor, expression_evaluator=period_evaluator
+            expression=model.power_loss_factor, expression_evaluator=period_evaluator
         )
         power_loss_factor = ExpressionTimeSeriesPowerLossFactor(time_series_expression=power_loss_factor_expression)
 
         rate_expression = TimeSeriesExpression(
-            expressions=model.rate, expression_evaluator=period_evaluator, condition=_map_condition(model)
+            expression=model.rate, expression_evaluator=period_evaluator, condition=_map_condition(model)
         )
         rate_standard_m3_day = ExpressionTimeSeriesFlowRate(
             time_series_expression=rate_expression,
@@ -320,21 +257,20 @@ class ConsumerFunctionMapper:
         )
 
         fluid_density_expression = TimeSeriesExpression(
-            expressions=model.fluid_density, expression_evaluator=period_evaluator
+            expression=model.fluid_density, expression_evaluator=period_evaluator
         )
         fluid_density = ExpressionTimeSeriesFluidDensity(time_series_expression=fluid_density_expression)
 
         suction_pressure_expression = TimeSeriesExpression(
-            expressions=model.suction_pressure, expression_evaluator=period_evaluator
+            expression=model.suction_pressure, expression_evaluator=period_evaluator
         )
         suction_pressure = ExpressionTimeSeriesPressure(time_series_expression=suction_pressure_expression)
 
         discharge_pressure_expression = TimeSeriesExpression(
-            expressions=model.discharge_pressure, expression_evaluator=period_evaluator
+            expression=model.discharge_pressure, expression_evaluator=period_evaluator
         )
         discharge_pressure = ExpressionTimeSeriesPressure(time_series_expression=discharge_pressure_expression)
 
-        pump_model = create_pump_model(pump_model_dto=energy_model)
         return PumpConsumerFunction(
             power_loss_factor=power_loss_factor,
             pump_function=pump_model,
@@ -348,38 +284,10 @@ class ConsumerFunctionMapper:
         self, model: YamlEnergyUsageModelCompressorTrainMultipleStreams, consumes: ConsumptionType, period: Period
     ):
         compressor_train_model = self.__references.get_compressor_model(model.compressor_train_model)
+        consumption_type = compressor_train_model.get_consumption_type()
 
-        if isinstance(compressor_train_model, CompressorWithTurbine):
-            require_interstage_pressure_variable_expression = (
-                compressor_train_model.compressor_train.has_interstage_pressure
-            )
-        elif isinstance(compressor_train_model, VariableSpeedCompressorTrainMultipleStreamsAndPressures):
-            require_interstage_pressure_variable_expression = compressor_train_model.has_interstage_pressure
-        else:
-            require_interstage_pressure_variable_expression = None
-
-        if require_interstage_pressure_variable_expression and model.interstage_control_pressure is None:
-            raise ValueError(
-                f"Energy model"
-                f" {model.compressor_train_model}"
-                f" requires {EcalcYamlKeywords.models_type_compressor_train_interstage_control_pressure} to be defined"
-            )
-        elif not require_interstage_pressure_variable_expression and model.interstage_control_pressure is not None:
-            raise ValueError(
-                f"Energy model"
-                f" {model.compressor_train_model}"
-                f" does not accept {EcalcYamlKeywords.models_type_compressor_train_interstage_control_pressure}"
-                f" to be defined"
-            )
-
-        energy_usage_type = _get_compressor_train_energy_usage_type(compressor_train_model)
-
-        energy_usage_type_as_consumption_type = (
-            ConsumptionType.ELECTRICITY if energy_usage_type == EnergyUsageType.POWER else ConsumptionType.FUEL
-        )
-
-        if consumes != energy_usage_type_as_consumption_type:
-            raise InvalidConsumptionType(actual=energy_usage_type_as_consumption_type, expected=consumes)
+        if consumes != consumption_type:
+            raise InvalidConsumptionType(actual=consumption_type, expected=consumes)
 
         regularity, expression_evaluator = self._period_subsets[period]
 
@@ -411,7 +319,6 @@ class ConsumerFunctionMapper:
             if model.interstage_control_pressure is not None
             else None
         )
-        compressor_model = create_compressor_model(compressor_model_dto=compressor_train_model)
         rates_per_stream: list[TimeSeriesFlowRate] = [
             ExpressionTimeSeriesFlowRate(
                 time_series_expression=TimeSeriesExpression(
@@ -424,7 +331,7 @@ class ConsumerFunctionMapper:
         ]
         return CompressorConsumerFunction(
             power_loss_factor_expression=power_loss_factor,
-            compressor_function=compressor_model,
+            compressor_function=compressor_train_model,
             rate_expression=rates_per_stream,
             suction_pressure_expression=suction_pressure,
             discharge_pressure_expression=discharge_pressure,
@@ -437,17 +344,11 @@ class ConsumerFunctionMapper:
         consumes: ConsumptionType,
         period: Period,
     ) -> CompressorConsumerFunction:
-        energy_model = self.__references.get_compressor_model(model.energy_function)
-        compressor_train_energy_usage_type = _get_compressor_train_energy_usage_type(compressor_train=energy_model)
+        compressor_model = self.__references.get_compressor_model(model.energy_function)
+        consumption_type = compressor_model.get_consumption_type()
 
-        energy_usage_type_as_consumption_type = (
-            ConsumptionType.ELECTRICITY
-            if compressor_train_energy_usage_type == EnergyUsageType.POWER
-            else ConsumptionType.FUEL
-        )
-
-        if consumes != energy_usage_type_as_consumption_type:
-            raise InvalidConsumptionType(actual=energy_usage_type_as_consumption_type, expected=consumes)
+        if consumes != consumption_type:
+            raise InvalidConsumptionType(actual=consumption_type, expected=consumes)
 
         regularity, expression_evaluator = self._period_subsets[period]
 
@@ -460,7 +361,6 @@ class ConsumerFunctionMapper:
             if model.power_loss_factor is not None
             else None
         )
-        compressor_model = create_compressor_model(compressor_model_dto=energy_model)
 
         return CompressorConsumerFunction(
             power_loss_factor_expression=power_loss_factor,
@@ -490,69 +390,111 @@ class ConsumerFunctionMapper:
         )
 
     def _map_compressor_system(
-        self, model: YamlEnergyUsageModelCompressorSystem, consumes: ConsumptionType
+        self, model: YamlEnergyUsageModelCompressorSystem, consumes: ConsumptionType, period: Period
     ) -> CompressorSystemConsumerFunction:
+        regularity, expression_evaluator = self._period_subsets[period]
         compressors = []
-        compressor_power_usage_type = set()
+        compressor_consumption_types: set[ConsumptionType] = set()
         for compressor in model.compressors:
             compressor_train = self.__references.get_compressor_model(compressor.compressor_model)
 
-            check_for_generic_from_input_compressor_chart_in_simplified_train_compressor_system(
-                compressor_train, name=compressor.name
-            )
-
             compressors.append(
                 ConsumerSystemComponent(
                     name=compressor.name,
-                    facility_model=create_compressor_model(compressor_train),
+                    facility_model=compressor_train,
                 )
             )
-            compressor_train_energy_usage_type = _get_compressor_train_energy_usage_type(compressor_train)
-            compressor_power_usage_type.add(compressor_train_energy_usage_type)
+            compressor_consumption_types.add(compressor_train.get_consumption_type())
 
         # Currently, compressor system (i.e. all of its compressors) is either electrical or turbine driven, and we
         # require all to have the same energy usage type
         # Later, we may allow the different compressors to have different energy usage types
-        if not _all_equal(compressor_power_usage_type):
-            raise ValueError("All compressors in a system must consume the same kind of energy")
+        if not _all_equal(compressor_consumption_types):
+            raise DomainValidationException("All compressors in a system must consume the same kind of energy")
 
         # Can't infer energy_usage_type when there are no compressors
-        energy_usage_type = (
-            compressor_power_usage_type.pop() if len(compressor_power_usage_type) == 1 else EnergyUsageType.POWER
+        consumption_type = (
+            compressor_consumption_types.pop()
+            if len(compressor_consumption_types) == 1
+            else ConsumptionType.ELECTRICITY
         )
 
-        energy_usage_type_as_consumption_type = (
-            ConsumptionType.ELECTRICITY if energy_usage_type == EnergyUsageType.POWER else ConsumptionType.FUEL
-        )
-
-        if consumes != energy_usage_type_as_consumption_type:
-            raise InvalidConsumptionType(actual=energy_usage_type_as_consumption_type, expected=consumes)
+        if consumes != consumption_type:
+            raise InvalidConsumptionType(actual=consumption_type, expected=consumes)
 
         operational_settings: list[ConsumerSystemOperationalSettingExpressions] = []
         for operational_setting in model.operational_settings:
             if operational_setting.rate_fractions is not None:
-                rate_fractions = convert_expressions(operational_setting.rate_fractions)  # type: ignore[arg-type]
-                total_system_rate = convert_expression(model.total_system_rate)
-                assert total_system_rate is not None
-                rates = map_rate_fractions(rate_fractions, total_system_rate)  # type: ignore[arg-type]
+                assert model.total_system_rate is not None
+                rate_expressions = [
+                    f"({model.total_system_rate}) {{*}} ({rate_fraction})"
+                    for rate_fraction in operational_setting.rate_fractions
+                ]
+
+                rates: list[TimeSeriesFlowRate] = [
+                    ExpressionTimeSeriesFlowRate(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=rate_expression,
+                            expression_evaluator=expression_evaluator,
+                            condition=_map_condition(model),
+                        ),
+                        regularity=regularity,
+                    )
+                    for rate_expression in rate_expressions
+                ]
             else:
-                rates = convert_expressions(operational_setting.rates)  # type: ignore[arg-type]
+                rates = [
+                    ExpressionTimeSeriesFlowRate(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=rate_expr,
+                            expression_evaluator=expression_evaluator,
+                            condition=_map_condition(model),
+                        ),
+                        regularity=regularity,
+                    )
+                    for rate_expr in operational_setting.rates
+                ]
 
             number_of_compressors = len(compressors)
 
             if operational_setting.suction_pressure is not None:
-                suction_pressures = [convert_expression(operational_setting.suction_pressure)] * number_of_compressors
+                suction_pressures = [
+                    ExpressionTimeSeriesPressure(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=operational_setting.suction_pressure, expression_evaluator=expression_evaluator
+                        )
+                    )
+                ] * number_of_compressors
             else:
                 assert operational_setting.suction_pressures is not None
-                suction_pressures = convert_expressions(operational_setting.suction_pressures)
+                suction_pressures = [
+                    ExpressionTimeSeriesPressure(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=pressure_expr, expression_evaluator=expression_evaluator
+                        )
+                    )
+                    for pressure_expr in operational_setting.suction_pressures
+                ]
 
             if operational_setting.discharge_pressure is not None:
                 discharge_pressures = [
-                    convert_expression(operational_setting.discharge_pressure)
+                    ExpressionTimeSeriesPressure(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=operational_setting.discharge_pressure,
+                            expression_evaluator=expression_evaluator,
+                        )
+                    )
                 ] * number_of_compressors
             else:
                 assert operational_setting.discharge_pressures is not None
-                discharge_pressures = convert_expressions(operational_setting.discharge_pressures)
+                discharge_pressures = [
+                    ExpressionTimeSeriesPressure(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=pressure_expr, expression_evaluator=expression_evaluator
+                        )
+                    )
+                    for pressure_expr in operational_setting.discharge_pressures
+                ]
 
             core_setting = CompressorSystemOperationalSettingExpressions(
                 rates=rates,
@@ -562,55 +504,121 @@ class ConsumerFunctionMapper:
             )
             operational_settings.append(core_setting)
 
-        power_loss_factor = convert_expression(model.power_loss_factor)
-        condition = convert_expression(_map_condition(model))
+        power_loss_factor_expression = TimeSeriesExpression(
+            expression=model.power_loss_factor, expression_evaluator=expression_evaluator
+        )
+        power_loss_factor = ExpressionTimeSeriesPowerLossFactor(time_series_expression=power_loss_factor_expression)
+
         return CompressorSystemConsumerFunction(
             consumer_components=compressors,
             operational_settings_expressions=operational_settings,
-            power_loss_factor_expression=power_loss_factor,  # type: ignore[arg-type]
-            condition_expression=condition,  # type: ignore[arg-type]
+            power_loss_factor=power_loss_factor,
         )
 
     def _map_pump_system(
-        self, model: YamlEnergyUsageModelPumpSystem, consumes: ConsumptionType
+        self, model: YamlEnergyUsageModelPumpSystem, consumes: ConsumptionType, period: Period
     ) -> PumpSystemConsumerFunction:
+        regularity, expression_evaluator = self._period_subsets[period]
         if consumes != ConsumptionType.ELECTRICITY:
             raise InvalidConsumptionType(actual=ConsumptionType.ELECTRICITY, expected=consumes)
 
         pumps = []
         for pump in model.pumps:
             pump_model = self.__references.get_pump_model(pump.chart)
-            pumps.append(ConsumerSystemComponent(name=pump.name, facility_model=create_pump_model(pump_model)))
+            pumps.append(ConsumerSystemComponent(name=pump.name, facility_model=pump_model))
 
         operational_settings: list[ConsumerSystemOperationalSettingExpressions] = []
         for operational_setting in model.operational_settings:
             if operational_setting.rate_fractions is not None:
-                rate_fractions = convert_expressions(operational_setting.rate_fractions)  # type: ignore[arg-type]
-                total_system_rate = convert_expression(model.total_system_rate)
-                assert total_system_rate is not None
-                rates = map_rate_fractions(rate_fractions, total_system_rate)  # type: ignore[arg-type]
+                assert model.total_system_rate is not None
+                rate_expressions = [
+                    f"({model.total_system_rate}) {{*}} ({rate_fraction})"
+                    for rate_fraction in operational_setting.rate_fractions
+                ]
+
+                rates: list[TimeSeriesFlowRate] = [
+                    ExpressionTimeSeriesFlowRate(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=rate_expression,
+                            expression_evaluator=expression_evaluator,
+                            condition=_map_condition(model),
+                        ),
+                        regularity=regularity,
+                    )
+                    for rate_expression in rate_expressions
+                ]
             else:
-                rates = convert_expressions(operational_setting.rates)  # type: ignore[arg-type]
+                rates = [
+                    ExpressionTimeSeriesFlowRate(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=rate_expr,
+                            expression_evaluator=expression_evaluator,
+                            condition=_map_condition(model),
+                        ),
+                        regularity=regularity,
+                    )
+                    for rate_expr in operational_setting.rates
+                ]
 
             number_of_pumps = len(pumps)
 
             if operational_setting.suction_pressure is not None:
-                suction_pressures = [convert_expression(operational_setting.suction_pressure)] * number_of_pumps
+                suction_pressures = [
+                    ExpressionTimeSeriesPressure(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=operational_setting.suction_pressure, expression_evaluator=expression_evaluator
+                        )
+                    )
+                ] * number_of_pumps
             else:
                 assert operational_setting.suction_pressures is not None
-                suction_pressures = convert_expressions(operational_setting.suction_pressures)
+                suction_pressures = [
+                    ExpressionTimeSeriesPressure(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=pressure_expr, expression_evaluator=expression_evaluator
+                        )
+                    )
+                    for pressure_expr in operational_setting.suction_pressures
+                ]
 
             if operational_setting.discharge_pressure is not None:
-                discharge_pressures = [convert_expression(operational_setting.discharge_pressure)] * number_of_pumps
+                discharge_pressures = [
+                    ExpressionTimeSeriesPressure(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=operational_setting.discharge_pressure,
+                            expression_evaluator=expression_evaluator,
+                        )
+                    )
+                ] * number_of_pumps
             else:
                 assert operational_setting.discharge_pressures is not None
-                discharge_pressures = convert_expressions(operational_setting.discharge_pressures)
+                discharge_pressures = [
+                    ExpressionTimeSeriesPressure(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=pressure_expr, expression_evaluator=expression_evaluator
+                        )
+                    )
+                    for pressure_expr in operational_setting.discharge_pressures
+                ]
 
             if operational_setting.fluid_densities:
-                fluid_densities = convert_expressions(operational_setting.fluid_densities)  # type: ignore[arg-type]
+                fluid_densities = [
+                    ExpressionTimeSeriesFluidDensity(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=fluid_density_expr, expression_evaluator=expression_evaluator
+                        )
+                    )
+                    for fluid_density_expr in operational_setting.fluid_densities
+                ]
             else:
                 assert model.fluid_density is not None
-                fluid_densities = [convert_expression(model.fluid_density)] * number_of_pumps
+                fluid_densities = [
+                    ExpressionTimeSeriesFluidDensity(
+                        time_series_expression=TimeSeriesExpression(
+                            expression=model.fluid_density, expression_evaluator=expression_evaluator
+                        )
+                    )
+                ] * number_of_pumps
 
             operational_settings.append(
                 PumpSystemOperationalSettingExpressions(
@@ -622,11 +630,13 @@ class ConsumerFunctionMapper:
                 )
             )
 
-        power_loss_factor = convert_expression(model.power_loss_factor)
-        condition = convert_expression(_map_condition(model))
+        power_loss_factor_expression = TimeSeriesExpression(
+            expression=model.power_loss_factor, expression_evaluator=expression_evaluator
+        )
+        power_loss_factor = ExpressionTimeSeriesPowerLossFactor(time_series_expression=power_loss_factor_expression)
+
         return PumpSystemConsumerFunction(
-            power_loss_factor_expression=power_loss_factor,  # type: ignore[arg-type]
-            condition_expression=condition,  # type: ignore[arg-type]
+            power_loss_factor=power_loss_factor,
             consumer_components=pumps,
             operational_settings_expressions=operational_settings,
         )
@@ -645,9 +655,9 @@ class ConsumerFunctionMapper:
                 elif isinstance(model, YamlEnergyUsageModelPump):
                     mapped_model = self._map_pump(model, consumes=consumes, period=period)
                 elif isinstance(model, YamlEnergyUsageModelCompressorSystem):
-                    mapped_model = self._map_compressor_system(model, consumes=consumes)
+                    mapped_model = self._map_compressor_system(model, consumes=consumes, period=period)
                 elif isinstance(model, YamlEnergyUsageModelPumpSystem):
-                    mapped_model = self._map_pump_system(model, consumes=consumes)
+                    mapped_model = self._map_pump_system(model, consumes=consumes, period=period)
                 elif isinstance(model, YamlEnergyUsageModelTabulated):
                     mapped_model = self._map_tabular(model=model, consumes=consumes, period=period)
                 elif isinstance(model, YamlEnergyUsageModelCompressorTrainMultipleStreams):
@@ -655,19 +665,7 @@ class ConsumerFunctionMapper:
                 else:
                     assert_never(model)
                 temporal_dict[period] = mapped_model
-            except InvalidConsumptionType as e:
-                raise InvalidEnergyUsageModelException(
-                    message=str(e),
-                    period=period,
-                    model=model,
-                ) from e
-            except ValueError as e:
-                raise InvalidEnergyUsageModelException(
-                    message=str(e),
-                    period=period,
-                    model=model,
-                ) from e
-            except InvalidExpressionError as e:
+            except (InvalidConsumptionType, ValueError, InvalidExpressionError, DomainValidationException) as e:
                 raise InvalidEnergyUsageModelException(
                     message=str(e),
                     period=period,
